(24) Software Test Engineer (Entry Level) | RTTS | LinkedIn

## 0 notifications total

# Software Test Engineer (Entry Level)

RTTS New York, NY 3 weeks ago Over 200 applicants

- Full-time · Entry level
- 51-200 employees · IT Services and IT Consulting
- 2 school alumni
- See how you compare to 244 applicants. Reactivate Premium

#### Job activity

- Application submitted 4 days ago

Submitted resume

## Recommended for you

Prepare for interviews Practice your answers to common interview questions and get feedback.

## About the job

Company Description

Who We Are

RTTS is the premier pure-play Quality Assurance and testing organization that specializes in test automation. Based in midtown Manhattan (but currently working remotely) and serving the Global 2000 companies since 1996, RTTS has helped 700+ companies reach their continuous deployment goals.

For more information, visit us at www.rttsweb.com

Job Description

What You’ll Be Doing

Using your strong programming and analytical skills, you’ll be responsible for coding custom solutions using cutting edge automated testing tools to support complex software applications. Other responsibilities include:

- Work alongside developers to verify application functionality, usability, scalability and data integrity.
- Ensure that the applications and/or data meet the specified requirements and that there are no defects in the application or underlying data.
- Create test plans, design test cases, automate tests, provide, manage test process, and evaluate defects.
- Develop and maintain reusable code libraries to help build streamlined and efficient automated test processes.
- Analyze and evaluate automation & defect metrics, providing feedback to developers, system & data architects and analysts & subject matter experts.

Assignments vary in length depending on our clients’ needs, providing you with the opportunity to learn new technologies and gain valuable exposure to many areas of business while working with client teams and experienced RTTS mentors.

Qualifications

What You Need

Must possess an undergraduate or graduate-level degree with a concentration in Computer Science, Information Technology, Mathematics, or another related field. Other qualifications include:

- Proficiency in a mainstream programming language: must have applicable skills in Java, Python, C++, C#, or C or other language
- Initiative to learn and utilize emerging technologies while working in a stimulating team environment
- Professional appearance and the ability to communicate complex technical information in a clear and tactful manner
- Applicants for employment must be authorized to work in the U.S.
- You must live within 50 miles of our office location (NYC)

Additional Information

What We Offer

$60-70K, depending on experience. Excellent benefits package including major medical, dental, 401K, tuition reimbursement, paid vacation and holidays, continuous learning and more. You can expect:

- Performance review and generous increase at 1 year + senior engineer exam and associated increase at 1 - 1.5 years. Performance reviews annually afterwards with potential for promotion.
- Ongoing development of your skills working with web technologies, server-side software and database platforms.
- The most comprehensive up-front training program in the industry. One-on-one mentoring is provided, an ideal fit for recent graduates and career changers.
- A challenging, supportive, educational and fun work environment. Our office culture encourages innovation and professional growth.
- All your information will be kept confidential according to EEO guidelines.

What Are You Waiting For?

If you’d like to start your IT career with RTTS, you should know that:

- Our office is located in midtown Manhattan, and since the advent of Covid-19, all employees have been working from home (Remote). Going forward, we are anticipating a hybrid work model with 1 – 2 days/week in the office and the rest working remote.
- Applicants for employment must be authorized to work in the U.S.

To learn more, visit our website at www.rttsweb.com/about-rtts/careers

## Set alert for similar jobs

Software Test Engineer, New York, NY

### About the company

RTTS
3,571 followers
Information Technology & Services 51-200 employees 121 on LinkedIn

RTTS is the premier pure-play QA & Testing organization that specializes in Test Automation. From its headquarters in New York, RTTS has been serving Global 2000 and mid-sized companies internationally since 1996.
QuerySurge, the enterprise data validation and testing solution, is the software division of RTTS (QuerySurge.com).
RTTS draws on its expertise utilizing proven best practices, expert test engineers and software solutions to provide assurance of your application functionality, scalability, and validating your data quality.
Key differentiators include:
------------------------------------
• A proven framework for software quality, including methodologies, templates, best practices, keyword engines, and software tools and utilities to improve the process.
• Unmatched experts in the field of software quality and testing
• Skilled engineers who have strong coding skills and are all full-time employees of RTTS
• The industry-leading automated data validation & ETL testing solution, built specifically for testing Big Data, Data Warehouses, and Business Intelligence reports. (www.QuerySurge.com)
• Strategic partnerships with IBM, Microsoft, Oracle, Teradata, SAP, Micro Focus, Cloudera, Snowflake, MongoDB and others
Strategic initiatives include:
- Testing-as-a-Service
- Managed Testing Services
- QA Process Assessment
- DevOps / DataOps implementation
- API Testing
- Automated Functional Testing
- Performance Engineering Services
- Mobile Application Testing Services
- Application Security Testing
- Data Validation Assessment
- Test Data Management Assessment
- Data Warehouse / ETL Testing
- Big Data Testing
- Data Migration Testing
- Enterprise App / ERP Testing
- BI Report Testing …

## More jobs

Job Title
Personal Assistant
Company Name
Harper Associates
Ann Arbor, MI
Be an early applicant

- Posted
  Just now
- Easy Apply

Job Title
Director, Financial Services (Hybrid)
Company Name
AAA National Office
Heathrow, FL
Be an early applicant

- Posted
  Just now

Job Title
Senior Employee Health & Safety Advisor
Company Name
First West Credit Union
City of Langley, British Columbia, Canada
1 alum

- Posted
  Just now

Job Title
System Administrator
Company Name
State of Georgia
Atlanta, GA
Be an early applicant

- Posted
  Just now
- Easy Apply

Job Title
Dining Room Supervisor
Company Name
Shannex Incorporated
Mississauga, ON
Be an early applicant

- Posted
  1 minute ago

Job Title
Environmental Health Safety Specialist
Company Name
DSJ Global
Grand Forks, ND
Be an early applicant

- Posted
  1 minute ago
- Easy Apply

Job Title
Senior .NET Developer
Company Name
Apex Systems
United States
8 alumni

- Posted
  1 minute ago
- Easy Apply

Job Title
Sr. Designer
Company Name
RATESDOTCA Group Ltd.
Toronto, ON
Be an early applicant

- Posted
  2 minutes ago
- Easy Apply

Job Title
Go Clinical Clinician Quebec, Canada
Company Name
ProPharma
Québec, QC
Be an early applicant

- Posted
  Just now

Job Title
Ruby on Rails Developer
Company Name
Mobile Programming LLC
Mumbai, Maharashtra, India
Be an early applicant

- Posted
  1 minute ago
- Easy Apply

Job Title
Supply Chain Analyst
Company Name
The Raymond Corporation
Muscatine, IA
Be an early applicant

- Posted
  2 minutes ago

Job Title
Product Quality Engineer
Company Name
Satechi
San Diego, CA
Be an early applicant

- Posted
  Just now
- Easy Apply

See more jobs like this

### Get ahead with Premium Career

Contact recruiters directly, see who's viewed your profile, stand out as a top applicant, and more.

Daniel and millions of other members use Premium

Reactivate Premium

Looking for talent?

Post a job